<?php

namespace App\Admin\Controllers;

use App\Admin\Repositories\DistInquiry;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Layout\Content;
use Dcat\Admin\Admin;

class DistInquiryController extends AdminController
{
    /**
     * page index
     */
    public function index(Content $content)
    {
        return $content
            ->header('Inquiry Management')
            ->description('all')
            ->breadcrumb(['text'=>'list','url'=>''])
            ->body($this->grid());
    }

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(DistInquiry::with(['distributor']), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('order_noumber');
            $grid->column('company_name');
            $grid->column('customer_name');
            $grid->column('email');
            $grid->column('consulting_products');
            //$grid->column('distributor.username', 'Distributor Username');
            $grid->column('distributor.name', 'Distributor Company Name');
            $grid->column('status')->using(config('dictionary.inquiryStatus'))->label([
                0 => 'default',
                1 => 'info',
                2 => 'success',
            ])->filter(Grid\Column\Filter\In::make(config('dictionary.inquiryStatus')));
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();
            //筛选
            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('order_noumber');
                $filter->equal('company_name');
                $filter->equal('customer_name');
                $filter->in('status', 'status')->multipleSelect(['0' => 'xx']);
            });
            //排序
            $grid->model()->orderBy("id",'desc');
            //按钮
            $grid->showQuickEditButton();
            $grid->disableCreateButton();
            $grid->disableEditButton();
            $grid->disableDeleteButton();
            $grid->disableBatchDelete();
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new DistInquiry(), function (Show $show) {
            $show->field('id');
            $show->field('order_noumber');
            $show->field('whats_app');
            $show->field('company_name');
            $show->field('customer_name');
            $show->field('email');
            $show->field('consulting_products');
            $show->field('freight_forwarder');
            $show->field('business_model');
            $show->field('ip_address');
            $show->field('status');
            $show->field('allocate_time');
            $show->field('content');
            $show->field('dist_user_id');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new DistInquiry(), function (Form $form) {
            $form->display('id');
            $form->text('order_noumber');
            $form->text('whats_app');
            $form->text('company_name');
            $form->text('customer_name');
            $form->text('email');
            $form->text('consulting_products');
            $form->text('freight_forwarder');
            $form->text('business_model');
            $form->text('ip_address');
            $form->text('status');
            $form->text('allocate_time');
            $form->text('content');
            $form->text('dist_user_id');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
